@@ -1,8 +1,6 @@
 #!/bin/sh
 set -x
-glib-gettextize --copy --force
 libtoolize --copy --automake
-intltoolize --automake --copy --force
 aclocal-1.8 || aclocal
 autoconf
 autoheader
